# Project Guarani

This library provides an implementation for authentication and authorization
of web applications. It provides support for JWTs, OAuth 2.1 and (soon) OpenID Connect.

For more details on each feature, please visit the respective documentation.

Any doubts and suggestions can be sent to my [email](mailto:eduardorbr7@gmail.com).
Just prepend the title with `#Guarani#`, and I will try my best to answer.

# License

This project is licensed under the MIT License.
For more details, please refer to the `LICENSE` file.
